# piptools_sync

> Short blurb about what your product does.

[![PyPI][pypi-image]][pypi-url]
[![Downloads][downloads-image]][downloads-url]
[![Status][status-image]][pypi-url]
[![Python Version][python-version-image]][pypi-url]
[![Format][format-image]][pypi-url]
[![Requirements][requirements-status-image]][requirements-status-url]
[![tests][tests-image]][tests-url]
[![Codecov][codecov-image]][codecov-url]
[![CodeFactor][codefactor-image]][codefactor-url]
[![Codeclimate][codeclimate-image]][codeclimate-url]
[![Lgtm alerts][lgtm-alerts-image]][lgtm-alerts-url]
[![Lgtm quality][lgtm-quality-image]][lgtm-quality-url]
[![CodeQl][codeql-image]][codeql-url]
[![readthedocs][readthedocs-image]][readthedocs-url]
[![pre-commit][pre-commit-image]][pre-commit-url]
[![pre-commit.ci status][pre-commit.ci-image]][pre-commit.ci-url]
[![Imports: isort][isort-image]][isort-url]
[![Code style: black][black-image]][black-url]
[![Checked with mypy][mypy-image]][mypy-url]
[![security: bandit][bandit-image]][bandit-url]
[![Commitizen friendly][commitizen-image]][commitizen-url]
[![Conventional Commits][conventional-commits-image]][conventional-commits-url]
[![DeepSource][deepsource-image]][deepsource-url]
[![license][license-image]][license-url]

One to two paragraph statement about your product and what it does.

![](assets/header.png)

## Installation

OS X & Linux:

```sh
pip3 install piptools_sync
```

Windows:

```sh
pip install piptools_sync
```

## Usage example

A few motivating and useful examples of how your product can be used. Spice this up with code blocks and potentially more screenshots.

_For more examples and usage, please refer to the [Wiki][wiki]._

## Development setup

Describe how to install all development dependencies and how to run an automated test-suite of some kind. Potentially do this for multiple platforms.

```sh
pip install --editable piptools_sync
```

## Documentation

### - [**Read the Docs**](https://piptools_sync.readthedocs.io/en/latest/)

### - [**Wiki**](https://github.com/Stephen-RA-King/piptools_sync/wiki)

## Meta

[![](assets/linkedin.png)](https://linkedin.com/in/stephen-k-3a4644210)
[![](assets/github.png)](https://github.com/Stephen-RA-King)
[![](assets/pypi.png)](https://pypi.org/project/piptools_sync/)
[![](assets/www.png)](https://www.justpython.tech)
[![](assets/email.png)](mailto:stephen.ra.king@gmail.com)
[![](assets/cv.png)](https://www.justpython.tech/cv)

Stephen R A King : stephen.ra.king@gmail.com

Distributed under the MIT license. See [license](license-url) for more information.

[https://github.com/Stephen-RA-King/piptools_sync](https://github.com/Stephen-RA-King/piptools_sync)

Created with Cookiecutter template: [**cc_template**][cc_template-url] version 1.2.1

<!-- Markdown link & img dfn's -->

[bandit-image]: https://img.shields.io/badge/security-bandit-yellow.svg
[bandit-url]: https://github.com/PyCQA/bandit
[black-image]: https://img.shields.io/badge/code%20style-black-000000.svg
[black-url]: https://github.com/psf/black
[cc_template-url]: https://github.com/Stephen-RA-King/cc_template
[codeclimate-image]: https://api.codeclimate.com/v1/badges/7fc352185512a1dab75d/maintainability
[codeclimate-url]: https://codeclimate.com/github/Stephen-RA-King/piptools_sync/maintainability
[codecov-image]: https://codecov.io/gh/Stephen-RA-King/piptools_sync/branch/main/graph/badge.svg
[codecov-url]: https://app.codecov.io/gh/Stephen-RA-King/piptools_sync
[codefactor-image]: https://www.codefactor.io/repository/github/Stephen-RA-King/piptools_sync/badge
[codefactor-url]: https://www.codefactor.io/repository/github/Stephen-RA-King/piptools_sync
[codeql-image]: https://github.com/Stephen-RA-King/piptools_sync/actions/workflows/codeql-analysis.yml/badge.svg
[codeql-url]: https://github.com/Stephen-RA-King/piptools_sync/actions/workflows/codeql-analysis.yml
[commitizen-image]: https://img.shields.io/badge/commitizen-friendly-brightgreen.svg
[commitizen-url]: http://commitizen.github.io/cz-cli/
[conventional-commits-image]: https://img.shields.io/badge/Conventional%20Commits-1.0.0-yellow.svg?style=flat-square
[conventional-commits-url]: https://conventionalcommits.org
[deepsource-image]: https://static.deepsource.io/deepsource-badge-light-mini.svg
[deepsource-url]: https://deepsource.io/gh/Stephen-RA-King/piptools_sync/?ref=repository-badge
[downloads-image]: https://static.pepy.tech/personalized-badge/piptools_sync?period=total&units=international_system&left_color=black&right_color=orange&left_text=Downloads
[downloads-url]: https://pepy.tech/project/piptools_sync
[format-image]: https://img.shields.io/pypi/format/piptools_sync
[isort-image]: https://img.shields.io/badge/%20imports-isort-%231674b1?style=flat&labelColor=ef8336
[isort-url]: https://github.com/pycqa/isort/
[lgtm-alerts-image]: https://img.shields.io/lgtm/alerts/g/Stephen-RA-King/piptools_sync.svg?logo=lgtm&logoWidth=18
[lgtm-alerts-url]: https://lgtm.com/projects/g/Stephen-RA-King/piptools_sync/alerts/
[lgtm-quality-image]: https://img.shields.io/lgtm/grade/python/g/Stephen-RA-King/piptools_sync.svg?logo=lgtm&logoWidth=18
[lgtm-quality-url]: https://lgtm.com/projects/g/Stephen-RA-King/piptools_sync/context:python
[license-image]: https://img.shields.io/pypi/l/piptools_sync
[license-url]: https://github.com/Stephen-RA-King/piptools_sync/blob/main/license
[mypy-image]: http://www.mypy-lang.org/static/mypy_badge.svg
[mypy-url]: http://mypy-lang.org/
[pre-commit-image]: https://img.shields.io/badge/pre--commit-enabled-brightgreen?logo=pre-commit&logoColor=white
[pre-commit-url]: https://github.com/pre-commit/pre-commit
[pre-commit.ci-image]: https://results.pre-commit.ci/badge/github/Stephen-RA-King/gitwatch/main.svg
[pre-commit.ci-url]: https://results.pre-commit.ci/latest/github/Stephen-RA-King/gitwatch/main
[pypi-url]: https://pypi.org/project/piptools_sync/
[pypi-image]: https://img.shields.io/pypi/v/piptools_sync.svg
[python-version-image]: https://img.shields.io/pypi/pyversions/piptools_sync
[readthedocs-image]: https://readthedocs.org/projects/piptools_sync/badge/?version=latest
[readthedocs-url]: https://piptools_sync.readthedocs.io/en/latest/?badge=latest
[requirements-status-image]: https://requires.io/github/Stephen-RA-King/piptools_sync/requirements.svg?branch=main
[requirements-status-url]: https://requires.io/github/Stephen-RA-King/piptools_sync/requirements/?branch=main
[status-image]: https://img.shields.io/pypi/status/piptools_sync.svg
[tests-image]: https://github.com/Stephen-RA-King/piptools_sync/actions/workflows/tests.yml/badge.svg
[tests-url]: https://github.com/Stephen-RA-King/piptools_sync/actions/workflows/tests.yml
[wiki]: https://github.com/Stephen-RA-King/piptools_sync/wiki
